#!/bin/env python

# Author: Patiga
# License: CC0
# Purpose: Figure out if calculating a bounding box around tiles layers could help with optimization

import twmap
import numpy as np
import sys

def bounding_box_size(tiles_layer):
    tiles = tiles_layer.tiles[:,:,0]
    non_zero_y, non_zero_x = np.nonzero(tiles)
    if len(non_zero_y) == 0:
        non_zero_y, non_zero_x = [0], [0]
    min_y = np.min(non_zero_y)
    max_y = np.max(non_zero_y)
    min_x = np.min(non_zero_x)
    max_x = np.max(non_zero_x)
    height = max_y - min_y + 1
    width = max_x - min_x + 1
    return width * height

map_count = 0
total_coverage = 0

for arg in sys.argv[1:]:
    try:
        map = twmap.Map(arg)
    except twmap.MapError as err:
        print(f"Couldn't load map {arg}: {err}")
        continue
    
    map_count += 1
    map_size = bounding_box_size(map.game_layer())
    tiles_layer_count = 0
    map_coverage = 0
    for group in map.groups:
        for layer in group.layers:
            if layer.kind() == "Tiles":
                tiles_layer_count += 1
                map_coverage += bounding_box_size(layer) / map_size
    if tiles_layer_count == 0:
        print(f"Map {arg} has no tiles layers")
        continue
    map_coverage /= tiles_layer_count
    print(f"{arg} coverage: {int(map_coverage * 100)}%")
    total_coverage += map_coverage

total_coverage /= map_count
print(f"Total coverage: {int(total_coverage * 100)}%")

